@@ -1,8 +1,8 @@
 #!/bin/sh
-exec > /dev/null
-/usr/local/bin/ghc-pkg update - << 'EOF'
-name: xmonad
-version: 0.7
+echo 'name: xmonad
+version: 0.9.1
+id: xmonad-0.9.1-8bb1b2e86f018a78105eaaa63e49bc47
+
 license: BSD3
 copyright:
 maintainer: xmonad@haskell.org
@@ -24,19 +24,26 @@ exposed: True
 exposed-modules: XMonad XMonad.Main XMonad.Core XMonad.Config
                  XMonad.Layout XMonad.ManageHook XMonad.Operations XMonad.StackSet
 hidden-modules:
-import-dirs: /usr/local/lib/xmonad-0.7/ghc-6.6.1
-library-dirs: /usr/local/lib/xmonad-0.7/ghc-6.6.1
-hs-libraries: HSxmonad-0.7
+import-dirs: /usr/local/lib/xmonad-0.9.1/ghc-6.12.3
+library-dirs: /usr/local/lib/xmonad-0.9.1/ghc-6.12.3
+hs-libraries: HSxmonad-0.9.1
 extra-libraries:
 extra-ghci-libraries:
-include-dirs: /usr/local/lib/xmonad-0.7/ghc-6.6.1/include
+include-dirs:
 includes:
-depends: base-2.1.1 X11-1.2.1 X11-extras-0.4 mtl-1.0.1 unix-2.1
+depends: X11-1.5.0.0-87011d3a15d7d77765d3e41c674b46ec
+         base-3.0.3.2-260693a92016991a03206b5a55f6a411
+         containers-0.3.0.0-ee442470d8dcc9e45f31677c400c5379
+         directory-1.0.1.1-debc5b242c6cb9e9d9ae96c3aeec5419
+         filepath-1.1.0.4-c303c646a99c2a24d2402008d247eb5f
+         mtl-1.1.0.2-9e35d291e0ab20c6aa18823de23bc2de
+         process-1.0.1.3-2568ceba2d6dc7c48536c5d78397f116
+         unix-2.4.0.2-7490d39532a63328e34fb16ff47045f5
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/xmonad-0.7/xmonad.haddock
-haddock-html: /usr/local/share/doc/xmonad-0.7
-EOF
+haddock-interfaces: /usr/local/share/doc/xmonad-0.9.1/html/xmonad.haddock
+haddock-html: /usr/local/share/doc/xmonad-0.9.1/html
+' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
